@@ -13,3 +13,6 @@ from .analysis import EvaluationEngine
 from .utterance import StanzaUtteranceEngine
 
 from .translate import SeamlessTranslationModel, GoogleTranslateEngine
+from .avqi import AVQIEngine
+
+from .diarization import PyannoteEngine
